==> CoffeeMud_5_9_6.zip: com/planet_ink/coffee_mud/Exits/OpenPrepositional.java <==
package com.planet_ink.coffee_mud.Exits;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

/*
   Copyright 2005-2017 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class OpenPrepositional extends StdOpenDoorway implements PrepositionExit
{
	@Override
	public String ID()
	{
		return "OpenPrepositional";
	}
	
	private String entryPreposition="";
	private String exitPreposition="";

	@Override
	public String Name()
	{
		return miscText;
	}

	@Override
	public String displayText()
	{
		return miscText;
	}

	@Override
	public String description()
	{
		return miscText;
	}

	@Override
	public void setMiscText(String newMiscText)
	{
		super.setMiscText(newMiscText);
		if(newMiscText.length()>0)
		{
			entryPreposition="through "+newMiscText;
			exitPreposition="through "+newMiscText;
		}
	}
	
	@Override
	public String getEntryPreposition()
	{
		return entryPreposition;
	}

	@Override
	public String getExitPreposition()
	{
		return exitPreposition;
	}

	@Override
	public void setEntryPreposition(String phrase)
	{
		entryPreposition=phrase;
	}

	@Override
	public void setExitPreposition(String phrase)
	{
		exitPreposition=phrase;
	}
}

==> CoffeeMud_5_9_8.zip: com/planet_ink/coffee_mud/Exits/OpenPrepositional.java <==
package com.planet_ink.coffee_mud.Exits;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

/*
   Copyright 2005-2019 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class OpenPrepositional extends StdOpenDoorway implements PrepositionExit
{
	@Override
	public String ID()
	{
		return "OpenPrepositional";
	}

	private String entryPreposition="";
	private String exitPreposition="";

	@Override
	public String Name()
	{
		return miscText;
	}

	@Override
	public String displayText()
	{
		return miscText;
	}

	@Override
	public String description()
	{
		return miscText;
	}

	@Override
	public void setMiscText(final String newMiscText)
	{
		super.setMiscText(newMiscText);
		if(newMiscText.length()>0)
		{
			entryPreposition="through "+newMiscText;
			exitPreposition="through "+newMiscText;
		}
	}

	@Override
	public String getEntryPreposition()
	{
		return entryPreposition;
	}

	@Override
	public String getExitPreposition()
	{
		return exitPreposition;
	}

	@Override
	public void setEntryPreposition(final String phrase)
	{
		entryPreposition=phrase;
	}

	@Override
	public void setExitPreposition(final String phrase)
	{
		exitPreposition=phrase;
	}
}
